@@ -1,4 +1,4 @@
-# $Id: Fastnexus.pm,v 1.4 2006/04/12 22:38:23 rvosa Exp $
+# $Id: Fastnexus.pm,v 1.5 2006/05/18 06:41:41 rvosa Exp $
 # Subversion: $Rev: 195 $
 package Bio::Phylo::Parsers::Fastnexus;
 use strict;
@@ -14,7 +14,6 @@ use Scalar::Util qw(blessed);
 use IO::String;
 
 # TODO: handle interleaved, handle ambiguity, mixed?
-
 # One line so MakeMaker sees it.
 use Bio::Phylo; our $VERSION = $Bio::Phylo::VERSION;
 
@@ -60,18 +59,18 @@ sub _new {
     # respective subs are called. Underscored fields are for parsing
     # context.
     my $self = {
-        '_current'   => undef,
-        '_previous'  => undef,
-        '_begin'     => undef,
-        '_ntax'      => undef,
-        '_nchar'     => undef,
-        '_gap'       => undef,
-        '_missing'   => undef,
-        '_i'         => undef,
-        '_tree'      => undef,
-        '_treename'  => undef,
-        '_treestart' => undef,
-        '_row'       => undef,
+        '_current'         => undef,
+        '_previous'        => undef,
+        '_begin'           => undef,
+        '_ntax'            => undef,
+        '_nchar'           => undef,
+        '_gap'             => undef,
+        '_missing'         => undef,
+        '_i'               => undef,
+        '_tree'            => undef,
+        '_treename'        => undef,
+        '_treestart'       => undef,
+        '_row'             => undef,
         '_found'           => 0,
         '_tokens'          => [],
         '_context'         => [],
@@ -105,9 +104,10 @@ sub _new {
         '#nexus'           => \&_nexus,
         'link'             => \&_link,
         ';'                => \&_semicolon,
-        'interleave' => sub { Bio::Phylo::Util::Exceptions::BadFormat->throw(
-            error => 'Sorry, no interleaved matrices',
-        )},
+        'interleave'       => sub {
+            Bio::Phylo::Util::Exceptions::BadFormat->throw(
+                error => 'Sorry, no interleaved matrices', );
+        },
     };
     bless $self, $class;
     return $self;
@@ -130,23 +130,22 @@ sub _new {
 *_from_string = \&_from_handle;
 
 sub _from_handle {
-    my $self = shift;
-    my %opts = @_;
+    my $self     = shift;
+    my %opts     = @_;
     my $comments = 0;
-
     if ( $opts{'-string'} ) {
         $opts{'-handle'} = IO::String->new( $opts{'-string'} );
     }
 
     # only from a file handle (but can be fooled with IO::String)
-    while ( readline($opts{-handle}) ) {
+    while ( readline( $opts{-handle} ) ) {
         chomp( my $line = $_ );
 
         # make spaces between punctuation and neighboring tokens (for split())
         $line =~ s/(;|=|,|\[|\])/ $1 /g;
 
         # strip comments, push remainder in @tokens
-        foreach my $token ( split(/\s+/, $line) ) {
+        foreach my $token ( split( /\s+/, $line ) ) {
             $comments++ if $token eq '[';
             if ( $token !~ m/^\s*$/ and not $comments ) {
                 push @{ $self->{'_tokens'} }, $token;
@@ -166,7 +165,7 @@ sub _from_handle {
         $quoted =~ s/\s+/_/g;
         $slurped = $begin . $quoted . $remainder;
     }
-    @{ $self->{'_tokens'} } = split(/\s+/, $slurped);
+    @{ $self->{'_tokens'} } = split( /\s+/, $slurped );
 
     # iterate over tokens, dispatch methods from %{ $self } table
     # This is the meat of the parsing, from here everything else is called.
@@ -176,9 +175,11 @@ sub _from_handle {
         if ( exists $self->{ lc( $self->{'_tokens'}->[$i] ) } ) {
             if ( ref $self->{ lc( $self->{'_tokens'}->[$i] ) } eq 'CODE' ) {
                 $self->{'_previous'} = $self->{'_current'};
-                $self->{'_current'} = lc( $self->{'_tokens'}->[$i] );
+                $self->{'_current'}  = lc( $self->{'_tokens'}->[$i] );
+
                 # pull code ref from dispatch table
                 my $c = $self->{ lc( $self->{'_tokens'}->[$i] ) };
+
                 # invoke as object method
                 $self->$c( $self->{'_tokens'}->[$i] );
                 $i++;
@@ -189,15 +190,22 @@ sub _from_handle {
             $self->$c( $self->{'_tokens'}->[$i] );
             $i++;
         }
+
         # note: global var $begin is switched 'on' by &_begin(), and 'off'
         # again by any one of the appropriate subsequent tokens, i.e.
         # taxa, data, characters and trees
-        if ( $self->{'_begin'} and not exists $self->{ lc( $self->{'_tokens'}->[$i] ) } ) {
+        if ( $self->{'_begin'}
+            and not exists $self->{ lc( $self->{'_tokens'}->[$i] ) } )
+        {
             my $private = $self->{'_tokens'}->[$i];
+
             # I think this is one of the few cases where 'until' is appropriate
-            until ( lc($self->{'_tokens'}->[$i - 2]) eq 'end' && $self->{'_tokens'}->[$i - 1] eq ';' ) {
+            until ( lc( $self->{'_tokens'}->[ $i - 2 ] ) eq 'end'
+                  && $self->{'_tokens'}->[ $i - 1 ] eq ';' )
+            {
                 $i++;
             }
+
             # here we've encountered 'end', ';' - $tokens[$i] should be 'begin'
             print "[ skipped private $private block ]\n" if $self->VERBOSE;
         }
@@ -207,15 +215,17 @@ sub _from_handle {
     my $taxa = [];
     foreach my $block ( @{ $self->{'_context'} } ) {
         if ( $block->_type == _TAXA_ ) {
-            push @{ $taxa }, $block;
+            push @{$taxa}, $block;
         }
         elsif ( $block->_type != _TAXA_ and $block->can('set_taxa') ) {
-            if ( $taxa->[-1] and $taxa->[-1]->can('_type') == _TAXA_ and not $block->get_taxa ) {
-                $block->set_taxa( $taxa->[-1] ); # XXX exception here?
+            if (    $taxa->[-1]
+                and $taxa->[-1]->can('_type') == _TAXA_
+                and not $block->get_taxa )
+            {
+                $block->set_taxa( $taxa->[-1] );    # XXX exception here?
             }
         }
     }
-
     return $self->{'_context'};
 }
 
@@ -230,7 +240,7 @@ their respective tokens are encountered.
 
 sub _nexus {
     my $self = shift;
-    print "#NEXUS\n" if uc($_[0]) eq '#NEXUS' and $self->VERBOSE;
+    print "#NEXUS\n" if uc( $_[0] ) eq '#NEXUS' and $self->VERBOSE;
 }
 
 sub _begin {
@@ -246,7 +256,7 @@ sub _taxa {
         $self->{'_begin'} = 0;
     }
     else {
-        $self->{'_current'} = 'link'; # because of 'link taxa = blah' construct
+        $self->{'_current'} = 'link';  # because of 'link taxa = blah' construct
     }
 }
 
@@ -273,7 +283,7 @@ sub _link {
         if ( not $self->{'_context'}->[-1]->get_taxa ) {
             foreach my $block ( @{ $self->{'_context'} } ) {
                 if ( $block->get_name and $block->get_name eq $link ) {
-                    $self->{'_context'}->[-1]->set_taxa( $block );
+                    $self->{'_context'}->[-1]->set_taxa($block);
                     last;
                 }
             }
@@ -300,7 +310,7 @@ sub _ntax {
 
 sub _taxlabels {
     my $self = shift;
-    if ( defined $_[0] and uc($_[0]) ne 'TAXLABELS' ) {
+    if ( defined $_[0] and uc( $_[0] ) ne 'TAXLABELS' ) {
         push @{ $self->{'_taxlabels'} }, _escape(shift);
     }
 }
@@ -338,9 +348,12 @@ sub _format {
 
 sub _datatype {
     my $self = shift;
-    if ( defined $_[0] and $_[0] !~ m/^(?:DATATYPE|=)/i and ! $self->{'_context'}->[-1]->get_type ) {
+    if (    defined $_[0]
+        and $_[0] !~ m/^(?:DATATYPE|=)/i
+        and !$self->{'_context'}->[-1]->get_type )
+    {
         my $datatype = shift;
-        $self->{'_context'}->[-1]->set_type( $datatype );
+        $self->{'_context'}->[-1]->set_type($datatype);
         print "DATATYPE = ", $datatype if $self->VERBOSE;
     }
 }
@@ -352,7 +365,7 @@ sub _items {
 
 sub _gap {
     my $self = shift;
-    if ( $_[0] !~ m/^(?:GAP|=)/i and ! $self->{'_gap'} ) {
+    if ( $_[0] !~ m/^(?:GAP|=)/i and !$self->{'_gap'} ) {
         $self->{'_gap'} = shift;
         print " GAP = ", $self->{'_gap'} if $self->VERBOSE;
         $self->{'_context'}->[-1]->set_gap( $self->{'_gap'} );
@@ -362,7 +375,7 @@ sub _gap {
 
 sub _missing {
     my $self = shift;
-    if ( $_[0] !~ m/^(?:MISSING|=)/i and ! $self->{'_missing'} ) {
+    if ( $_[0] !~ m/^(?:MISSING|=)/i and !$self->{'_missing'} ) {
         $self->{'_missing'} = shift;
         print " MISSING = ", $self->{'_missing'} if $self->VERBOSE;
         $self->{'_context'}->[-1]->set_missing( $self->{'_missing'} );
@@ -378,7 +391,6 @@ sub _symbols {
 }
 
 sub _charstatelabels {
-
 }
 
 sub _matrix {
@@ -393,9 +405,9 @@ sub _matrix {
         $self->{'_context'}->[-1]->set_ntax( $self->{'_ntax'} );
         $self->{'_context'}->[-1]->set_nchar( $self->{'_nchar'} );
         if ( $self->VERBOSE ) {
-            print "MATRIX [ ",  $self->{'_context'}->[-1]->get_type;
-            print " nchar: ",   $self->{'_context'}->[-1]->get_nchar;
-            print " ntax: ",    $self->{'_context'}->[-1]->get_ntax;
+            print "MATRIX [ ", $self->{'_context'}->[-1]->get_type;
+            print " nchar: ",  $self->{'_context'}->[-1]->get_nchar;
+            print " ntax: ",   $self->{'_context'}->[-1]->get_ntax;
             print " ]\n";
         }
         return;
@@ -403,23 +415,31 @@ sub _matrix {
 
     # no taxon name, starting a new row
     elsif ( not defined $self->{'_row'} ) {
-        $self->{'_row'} = _escape($token); # initialize taxon name
-        $self->{'_matrix'}->{ $self->{'_row'} } = []; # initialize char array ref
+        $self->{'_row'} = _escape($token);    # initialize taxon name
+        $self->{'_matrix'}->{ $self->{'_row'} } =
+          [];                                 # initialize char array ref
         return;
     }
 
     # continuing row, not reached nchar
-    elsif ( scalar @{ $self->{'_matrix'}->{ $self->{'_row'} } } < $self->{'_nchar'} ) {
+    elsif (
+        scalar @{ $self->{'_matrix'}->{ $self->{'_row'} } } <
+        $self->{'_nchar'} )
+    {
         if ( uc $self->{'_matrixtype'} eq 'CONTINUOUS' ) {
             push @{ $self->{'_matrix'}->{ $self->{'_row'} } }, $token if $token;
         }
         else {
-            push @{ $self->{'_matrix'}->{ $self->{'_row'} } }, grep {/^.$/} split(//,$token);
+            push @{ $self->{'_matrix'}->{ $self->{'_row'} } },
+              grep { /^.$/ } split( //, $token );
         }
     }
 
     # finishing row, reached nchar
-    if ( scalar @{ $self->{'_matrix'}->{ $self->{'_row'} } } == $self->{'_nchar'} ) {
+    if (
+        scalar @{ $self->{'_matrix'}->{ $self->{'_row'} } } ==
+        $self->{'_nchar'} )
+    {
         my $taxon;
 
         # find / create matching taxon, matrix is linked
@@ -432,10 +452,9 @@ sub _matrix {
 
             # taxon does not exist yet
             if ( not $taxon ) {
-                $taxon = Bio::Phylo::Taxa::Taxon->new(
-                    '-name' => $self->{'_row'},
-                );
-                $taxa->insert( $taxon );
+                $taxon =
+                  Bio::Phylo::Taxa::Taxon->new( '-name' => $self->{'_row'}, );
+                $taxa->insert($taxon);
             }
         }
 
@@ -444,7 +463,7 @@ sub _matrix {
 
             # try to find the most recent taxa block
             my $taxa;
-            for ( my $i = $#{ $self->{'_context'} }; $i >= 0; $i-- ) {
+            for ( my $i = $#{ $self->{'_context'} } ; $i >= 0 ; $i-- ) {
                 if ( $self->{'_context'}->[$i]->_type == _TAXA_ ) {
                     $taxa = $self->{'_context'}->[$i];
                     last;
@@ -453,18 +472,17 @@ sub _matrix {
 
             # create new taxa block
             if ( not $taxa ) {
-                $taxa = Bio::Phylo::Taxa->new(
-                    '-name' => 'Untitled_taxa_block',
-                );
+                $taxa =
+                  Bio::Phylo::Taxa->new( '-name' => 'Untitled_taxa_block', );
             }
 
             # create new taxon
-            $taxon = Bio::Phylo::Taxa::Taxon->new(
-                '-name' => $self->{'_row'},
-            );
-            $taxa->insert( $taxon );
-            unshift @{ $self->{'_context'} }, $taxa; # place new taxa as first
-            $self->{'_context'}->[-1]->set_taxa( $taxa ); # link current block to taxa
+            $taxon =
+              Bio::Phylo::Taxa::Taxon->new( '-name' => $self->{'_row'}, );
+            $taxa->insert($taxon);
+            unshift @{ $self->{'_context'} }, $taxa;   # place new taxa as first
+            $self->{'_context'}->[-1]->set_taxa($taxa)
+              ;    # link current block to taxa
         }
 
         # create new datum
@@ -476,7 +494,8 @@ sub _matrix {
         );
         my @rows = keys %{ $self->{'_matrix'} };
         if ( scalar @rows < $self->{'_ntax'} ) {
-            $self->{'_context'}->[-1]->_is_flat(1); # only run _flatten the last time
+            $self->{'_context'}->[-1]->_is_flat(1)
+              ;    # only run _flatten the last time
         }
         else {
             $self->{'_context'}->[-1]->_is_flat(0);
@@ -484,29 +503,33 @@ sub _matrix {
 
         # insert new datum in matrix
         $self->{'_context'}->[-1]->insert($datum);
-
         if ( $self->VERBOSE ) {
             print $self->{'_row'}, "\t";
             if ( uc $self->{'_matrixtype'} eq 'CONTINUOUS' ) {
-                print join(' ', @{ $self->{'_matrix'}->{ $self->{'_row'} } }), "\n";
+                print join( ' ', @{ $self->{'_matrix'}->{ $self->{'_row'} } } ),
+                  "\n";
             }
             else {
-                print join('', @{ $self->{'_matrix'}->{ $self->{'_row'} } }), "\n";
+                print join( '', @{ $self->{'_matrix'}->{ $self->{'_row'} } } ),
+                  "\n";
             }
         }
         $self->{'_row'} = undef;
     }
 
     # Let's avoid these!
-    elsif ( scalar @{ $self->{'_matrix'}->{ $self->{'_row'} } } > $self->{'_nchar'} ) {
+    elsif (
+        scalar @{ $self->{'_matrix'}->{ $self->{'_row'} } } >
+        $self->{'_nchar'} )
+    {
         Bio::Phylo::Util::Exceptions::BadFormat->throw(
-            error => "More characters than expected",
-        );
+            error => "More characters than expected", );
     }
-    elsif ( not $self->{'_row'} and scalar { keys %{ $self->{'_matrix'} } } > $self->{'_ntax'} ) {
+    elsif ( not $self->{'_row'}
+        and scalar { keys %{ $self->{'_matrix'} } } > $self->{'_ntax'} )
+    {
         Bio::Phylo::Util::Exceptions::BadFormat->throw(
-            error => "More taxa than expected",
-        );
+            error => "More taxa than expected", );
     }
 }
 
@@ -532,7 +555,7 @@ sub _translate {
     }
     elsif ( defined $self->{'_i'} and defined $_[0] and $_[0] ne ';' ) {
         my $i = $self->{'_i'};
-        $self->{'_translate'}->[$i] = _escape($_[0]);
+        $self->{'_translate'}->[$i] = _escape( $_[0] );
         print $self->{'_translate'}->[$i] if $self->VERBOSE;
         $self->{'_i'} = undef;
     }
@@ -541,7 +564,7 @@ sub _translate {
 sub _tree {
     my $self = shift;
     if ( not $self->{'_treename'} and $_[0] !~ m/^U?TREE$/i ) {
-        $self->{'_treename'} = _escape($_[0]);
+        $self->{'_treename'} = _escape( $_[0] );
     }
     if ( $_[0] eq '=' and not $self->{'_treestart'} ) {
         $self->{'_treestart'} = 1;
@@ -552,18 +575,22 @@ sub _tree {
 
     # tr/// returns # of replacements, hence can be used to check
     # tree description is balanced
-    if ( $self->{'_treestart'} and $self->{'_tree'} and $self->{'_tree'} =~ tr/(/(/ == $self->{'_tree'} =~ tr/)/)/ ) {
+    if (    $self->{'_treestart'}
+        and $self->{'_tree'}
+        and $self->{'_tree'} =~ tr/(/(/ == $self->{'_tree'} =~ tr/)/)/ )
+    {
         my $translated = $self->{'_tree'};
         my $translate  = $self->{'_translate'};
-        for my $i ( 1 .. $#{ $translate } ) {
+        for my $i ( 1 .. $#{$translate} ) {
             $translated =~ s/(\(|,)$i(,|\)|:)/$1$translate->[$i]$2/;
         }
         my $tree_obj = parse(
             '-format' => 'fastnewick',
             '-string' => $translated . ';',
         )->first->set_name( $self->{'_treename'} );
-        $self->{'_context'}->[-1]->insert( $tree_obj );
-        print "TREE ", $self->{'_treename'}, " = ", $self->{'_tree'} if $self->VERBOSE;
+        $self->{'_context'}->[-1]->insert($tree_obj);
+        print "TREE ", $self->{'_treename'}, " = ", $self->{'_tree'}
+          if $self->VERBOSE;
         $self->{'_treestart'} = 0;
         $self->{'_tree'}      = undef;
         $self->{'_treename'}  = undef;
@@ -572,7 +599,7 @@ sub _tree {
 
 sub _end {
     my $self = shift;
-    print "END" if uc($_[0]) eq 'END' and $self->VERBOSE;
+    print "END" if uc( $_[0] ) eq 'END' and $self->VERBOSE;
     $self->{'_translate'} = [];
 }
 
@@ -585,13 +612,13 @@ sub _semicolon {
         if ( not $self->{'_context'}->[-1]->get_ntax ) {
             my $taxon = {};
             foreach my $row ( @{ $self->{'_context'}->[-1]->get_entities } ) {
-                $taxon->{$row->get_taxon}++;
+                $taxon->{ $row->get_taxon }++;
             }
-            my $ntax = scalar keys %{ $taxon };
-            $self->{'_context'}->[-1]->set_ntax( $ntax );
+            my $ntax = scalar keys %{$taxon};
+            $self->{'_context'}->[-1]->set_ntax($ntax);
         }
         eval { $self->{'_context'}->[-1]->validate };
-        if ( $@ ) {
+        if ($@) {
             $@->rethrow;
         }
     }
@@ -599,21 +626,19 @@ sub _semicolon {
         print "TAXLABELS\n" if $self->VERBOSE;
         foreach my $name ( @{ $self->{'_taxlabels'} } ) {
             print "\t$name\n" if $self->VERBOSE;
-            my $taxon = Bio::Phylo::Taxa::Taxon->new(
-                '-name' => $name,
-            );
+            my $taxon = Bio::Phylo::Taxa::Taxon->new( '-name' => $name, );
             $self->{'_context'}->[-1]->insert($taxon);
         }
         $self->{'_context'}->[-1]->set_ntax( $self->{'_ntax'} );
         eval { $self->{'_context'}->[-1]->validate };
-        if ( $@ ) {
+        if ($@) {
             $@->rethrow;
         }
         $self->{'_taxlabels'} = [];
     }
     elsif ( uc $self->{'_previous'} eq 'SYMBOLS' ) {
         if ( $self->VERBOSE ) {
-            print 'SYMBOLS = "', join(' ', @{ $self->{'_symbols'} }), '"';
+            print 'SYMBOLS = "', join( ' ', @{ $self->{'_symbols'} } ), '"';
         }
         $self->{'_context'}->[-1]->set_symbols( $self->{'_symbols'} );
         $self->{'_symbols'} = [];
@@ -663,7 +688,7 @@ and then you'll automatically be notified of progress on your bug as I make
 changes. Be sure to include the following in your request or comment, so that
 I know what version you're using:
 
-$Id: Fastnexus.pm,v 1.4 2006/04/12 22:38:23 rvosa Exp $
+$Id: Fastnexus.pm,v 1.5 2006/05/18 06:41:41 rvosa Exp $
 
 =head1 AUTHOR
 
